# Release notes

<!-- do not remove -->

## 0.1.9

### New Features

- `conda_output_path` windows compatibility ([#44](https://github.com/fastai/fastrelease/issues/44))


## 0.1.7

### New Features

- add `chk_conda_rel` ([#43](https://github.com/fastai/fastrelease/issues/43))


## 0.1.2

### Bugs Squashed

- changelog not appearing in release body ([#39](https://github.com/fastai/fastrelease/issues/39))


## 0.1.1

### New Features

- remove version number from start of release body ([#38](https://github.com/fastai/fastrelease/issues/38))


## 0.1.0

### New Features

- update to use new `ghapi` library ([#37](https://github.com/fastai/fastrelease/issues/37))


## 0.0.21

### Bugs Squashed

- conda builds failing with `fastrelease_conda_package` ([#36](https://github.com/fastai/fastrelease/issues/36))


## 0.0.19

### New Features

- read github token from env `FASTRELEASE_TOKEN` if available ([#35](https://github.com/fastai/fastrelease/issues/35))


## 0.0.17

### New Features

- add `fastrelease_bump_version` ([#34](https://github.com/fastai/fastrelease/issues/34))


## 0.0.13

### New Features

- use `store_true` in cli ([#33](https://github.com/fastai/fastrelease/issues/33))


## 0.0.12

### Bugs Squashed

- problems with names with hyphens ([#32](https://github.com/fastai/fastrelease/issues/32))


## 0.0.11

### New Features

- remove auto-linebreaks for CHANGELOG ([#31](https://github.com/fastai/fastrelease/issues/31))


## 0.0.9

### New Features

- Add contributor name in issue text ([#30](https://github.com/fastai/fastrelease/pull/30)), thanks to [@Nilanshrajput](https://github.com/Nilanshrajput)

## 0.0.8

### New Features

- new CLI: `fastrelease` for doing both changelog and release ([#27](https://github.com/fastai/fastrelease/issues/27))
- move conda packager from `nbdev` ([#23](https://github.com/fastai/fastrelease/issues/23))

## 0.0.7

### New Features

- add latest release notes to release body ([#25](https://github.com/fastai/fastrelease/issues/25))
- add `debug` flag to `fastrelease_changelog` ([#24](https://github.com/fastai/fastrelease/issues/24))

### Bugs Squashed

- `fastrelease_changelog` `debug` param not optional ([#26](https://github.com/fastai/fastrelease/issues/26))

## 0.0.3

### New Features

- Create a GitHub Action For Change Logs ([#6](https://github.com/fastai/fastrelease/issues/6))
  - Creates a GitHub Action that generates a ChangeLog automatically based on Issue and PR Titles.

## 0.0.2

### New Features

- Add CLI ([#2](https://github.com/fastai/fastrelease/issues/2))

## 0.0.1

### New Features

- Standalone repo with no external dependencies ([#1](https://github.com/fastai/fastrelease/issues/1))

